========================
nmraspecds documentation
========================

Welcome! This is the documentation for nmraspecds, a Python package for reading in, manipulating and plotting NMR spectra with the ultimate goal to document all steps and make the history of the processed spectrum reproducible.


Features
========

A list of features:

* Dataset containing main information on the dataset (not yet completed).


And to make it even more convenient for users and future-proof:

* Open source project written in Python (>= 3.7)

* Developed fully test-driven

* Extensive user and API documentation



.. warning::
  nmraspecds is currently under active development and still considered in Alpha development state. Therefore, expect frequent changes in features and public APIs that may break your own code. Nevertheless, feedback as well as feature requests are highly welcome.


Installation
============

To install the nmraspecds package on your computer (sensibly within a Python virtual environment), open a terminal (activate your virtual environment), and type in the following:

.. code-block:: bash

    pip install nmraspecds


License
=======

This program is free software: you can redistribute it and/or modify it under the terms of the **BSD License**.

